@@ -53,18 +53,19 @@ namespace canvas
       TextLine lineAt(size_t i) const;
 
       /// Get nearest line to given y-coordinate
+#if OSG_VERSION_LESS_THAN(3,6,5)
       TextLine nearestLine(float pos_y) const;
-
-
       SGVec2i sizeForWidth(int w) const;
-
-      osg::BoundingBox
-#if OSG_VERSION_LESS_THAN(3,3,2)
-      computeBound()
 #else
-      computeBoundingBox()
+      TextLine nearestLine(float pos_y);
+      SGVec2i sizeForWidth(int w);
+#endif
+
+#if OSG_VERSION_LESS_THAN(3,3,2)
+      osg::BoundingBox computeBound() const override;
+#else
+      osg::BoundingBox computeBoundingBox() const override;
 #endif
-      const override;
 
     protected:
       friend class TextLine;
@@ -126,7 +127,6 @@ namespace canvas
 
     _quads = &text->_textureGlyphQuadMap.begin()->second;
 
-
 #if OSG_VERSION_LESS_THAN(3,5,6)
     GlyphQuads::LineNumbers const& line_numbers = _quads->_lineNumbers;
     GlyphQuads::LineNumbers::const_iterator begin_it =
@@ -140,8 +140,7 @@ namespace canvas
     _end = std::upper_bound(begin_it, line_numbers.end(), _line)
          - line_numbers.begin();
 #else
-//OSG:TODO: Need 3.5.6 version of this
-
+  // TODO: Need 3.5.6 version of this
 #endif
   }
 
@@ -171,11 +170,17 @@ namespace canvas
 
     if( empty() )
       return pos;
+
+#if OSG_VERSION_GREATER_OR_EQUAL(3,5,6)
+    // TODO: need 3.5.6 version of this.
+#else
 #if OSG_VERSION_LESS_THAN(3,3,5)
       GlyphQuads::Coords2 const& coords = _quads->_coords;
-#elif OSG_VERSION_LESS_THAN(3,5,6)
+#else
       GlyphQuads::Coords2 refCoords = _quads->_coords;
       GlyphQuads::Coords2::element_type &coords = *refCoords.get();
+#endif
+
       size_t global_i = _begin + i;
 
       if (global_i == _begin)
@@ -198,8 +203,6 @@ namespace canvas
               // position at center between characters
               pos.x() = 0.5 * (prev_r + cur_l);
       }
-#else
-//OSG:TODO: need 3.5.7 version of this.
 #endif
 
     return pos;
@@ -208,16 +211,21 @@ namespace canvas
   //----------------------------------------------------------------------------
   osg::Vec2 TextLine::nearestCursor(float x) const
   {
-    if( empty() )
+    if (empty())
       return cursorPos(0);
 
-    GlyphQuads::Glyphs const& glyphs = _quads->_glyphs;
+#if OSG_VERSION_GREATER_OR_EQUAL(3,5,6)
+  // TODO: need 3.5.7 version of this.
+	return cursorPos(0);
+#else
 #if OSG_VERSION_LESS_THAN(3,3,5)
     GlyphQuads::Coords2 const& coords = _quads->_coords;
-#elif OSG_VERSION_LESS_THAN(3,5,6)
-
+#else
     GlyphQuads::Coords2 refCoords = _quads->_coords;
     GlyphQuads::Coords2::element_type &coords = *refCoords.get();
+#endif
+
+    GlyphQuads::Glyphs const& glyphs = _quads->_glyphs;
 
     float const HIT_FRACTION = 0.6;
     float const character_width = _text->getCharacterHeight()
@@ -237,9 +245,6 @@ namespace canvas
     }
 
     return cursorPos(i - _begin);
-#else
-//OSG:TODO: need 3.5.7 version of this.
-	return cursorPos(0);
 #endif
   }
 
@@ -319,9 +324,16 @@ namespace canvas
   }
 
   //----------------------------------------------------------------------------
+#if OSG_VERSION_LESS_THAN(3,6,5)
   TextLine Text::TextOSG::nearestLine(float pos_y) const
   {
     osgText::Font const* font = getActiveFont();
+#else
+  TextLine Text::TextOSG::nearestLine(float pos_y)
+  {
+    auto font = getActiveFont();
+#endif
+
     if( !font || lineCount() <= 0 )
       return TextLine(0, this);
 
@@ -343,12 +355,21 @@ namespace canvas
   // simplified version of osgText::Text::computeGlyphRepresentation() to
   // just calculate the size for a given weight. Glpyh calculations/creating
   // is not necessary for this...
+#if OSG_VERSION_LESS_THAN(3,6,5)
   SGVec2i Text::TextOSG::sizeForWidth(int w) const
+#else
+  SGVec2i Text::TextOSG::sizeForWidth(int w)
+#endif
   {
     if( _text.empty() )
       return SGVec2i(0, 0);
 
+#if OSG_VERSION_LESS_THAN(3,6,5)
     osgText::Font* activefont = const_cast<osgText::Font*>(getActiveFont());
+#else
+    auto activefont = getActiveFont();
+#endif
+
     if( !activefont )
       return SGVec2i(-1, -1);
 
@@ -628,19 +649,16 @@ namespace canvas
   }
 
   //----------------------------------------------------------------------------
-  osg::BoundingBox
 #if OSG_VERSION_LESS_THAN(3,3,2)
-  Text::TextOSG::computeBound()
+  osg::BoundingBox Text::TextOSG::computeBound() const
 #else
-  Text::TextOSG::computeBoundingBox()
+  osg::BoundingBox Text::TextOSG::computeBoundingBox() const
 #endif
-  const
   {
-    osg::BoundingBox bb =
 #if OSG_VERSION_LESS_THAN(3,3,2)
-      osgText::Text::computeBound();
+      osg::BoundingBox bb = osgText::Text::computeBound();
 #else
-      osgText::Text::computeBoundingBox();
+      osg::BoundingBox bb = osgText::Text::computeBoundingBox();
 #endif
 
 #if OSG_VERSION_LESS_THAN(3,1,0)
@@ -727,9 +745,9 @@ namespace canvas
   }
 
 #else
-  void Text::TextOSG::computePositionsImplementation() 
+  void Text::TextOSG::computePositionsImplementation()
   {
-          TextBase::computePositionsImplementation();
+    TextBase::computePositionsImplementation();
   }
 #endif
  //----------------------------------------------------------------------------
