@@ -84,7 +84,7 @@ SGXmlSound::~SGXmlSound()
     _pitch.clear();
 }
 
-void
+bool
 SGXmlSound::init( SGPropertyNode *root,
                   SGPropertyNode *node,
                   SGSampleGroup *sgrp,
@@ -315,8 +315,8 @@ SGXmlSound::init( SGPropertyNode *root,
    string soundFileStr = node->getStringValue("path", "");
    _sample = new SGSoundSample(soundFileStr.c_str(), path);
    if (!_sample->file_path().exists()) {
-      throw sg_io_exception("XML sound: couldn't find file: '" + soundFileStr + "'");
-      return;
+      SG_LOG(SG_SOUND, SG_WARN, "XML sound: couldn't find file: '" + soundFileStr + "'");
+      return false;
    }
 
    _sample->set_relative_position( offset_pos );
@@ -328,6 +328,8 @@ SGXmlSound::init( SGPropertyNode *root,
    _sample->set_volume( v );
    _sample->set_pitch( p );
    _sgrp->add( _sample, _name );
+
+   return true;
 }
 
 void
@@ -414,9 +416,11 @@ SGXmlSound::update (double dt)
       double v = 1.0;
 
       if (_volume[i].expr) {
-         v = _volume[i].expr->getValue(nullptr);
-         expr = true;
-         continue;
+          double expression_value = _volume[i].expr->getValue(nullptr);
+          if (expression_value >= 0)
+              volume *= expression_value;
+		  expr = true;
+		  continue;
       }
 
       if (_volume[i].prop) {
@@ -437,19 +441,23 @@ SGXmlSound::update (double dt)
 
       if (_volume[i].max && (v > _volume[i].max))
          v = _volume[i].max;
-
       else if (v < _volume[i].min)
          v = _volume[i].min;
 
-      if (_volume[i].subtract)				// Hack!
-         volume = _volume[i].offset - v;
 
+      if (_volume[i].subtract){				// Hack!
+          v = v + _volume[i].offset;
+          if (v >= 0)
+            volume = volume * v;
+      }
       else {
-         volume_offset += _volume[i].offset;
-         volume *= v;
+          if (v >= 0) {
+              volume_offset += _volume[i].offset;
+              volume = volume * v;
+          }
       }
    }
-
+   
    //
    // Update the pitch
    //
@@ -462,9 +470,9 @@ SGXmlSound::update (double dt)
       double p = 1.0;
 
       if (_pitch[i].expr) {
-         p = _pitch[i].expr->getValue(nullptr);
-         expr = true;
-         continue;
+          pitch *= _pitch[i].expr->getValue(nullptr);
+          expr = true;
+          continue;
       }
 
       if (_pitch[i].prop) {
