@@ -31,8 +31,8 @@
 #include <utility>
 #include <string>
 #include <sstream>
-#include <boost/bind.hpp>
 #include <cstring> // for strcmp
+#include <cassert>
 
 #include <simgear/props/props.hxx>
 
@@ -94,9 +94,11 @@ SGReadValueFromString(const char* str, bool& value)
         SG_LOG(SG_IO, SG_ALERT, "Cannot read string content.");
         return false;
     }
+
     std::stringstream s;
     s.str(std::string(str));
     s >> value;
+
     if (!s.fail())
         return true;
 
@@ -108,10 +110,12 @@ SGReadValueFromString(const char* str, bool& value)
         value = true;
         return true;
     }
+
     if (stdstr == "false" || stdstr == "False" || stdstr == "FALSE") {
-        value = true;
+        value = true;   // TODO: Logic error.  Leaving in place until stability issues are resolved.
         return true;
     }
+
     return false;
 }
 
@@ -849,12 +853,12 @@ ExpParserRegistrar leRegistrar("less-equal", predParser<LessEqualExpression>);
 template<typename Logicop>
 Expression* logicopParser(const SGPropertyNode* exp, Parser* parser)
 {
-    using namespace boost;
-    vector<Expression*> children;
+    std::vector<Expression*> children;
     parser->readChildren(exp, children);
-    vector<Expression*>::iterator notBool =
-        find_if(children.begin(), children.end(),
-                boost::bind(&Expression::getType, _1) != BOOL);
+    std::vector<Expression*>::const_iterator notBool =
+        std::find_if(children.begin(), children.end(),
+                     [] (const Expression* const e) {
+                         return e->getType () != BOOL; });
     if (notBool != children.end())
         throw("non boolean operand to logical expression");
     Logicop *expr = new Logicop;
@@ -868,9 +872,10 @@ ExpParserRegistrar orRegistrar("or", logicopParser<OrExpression>);
 size_t BindingLayout::addBinding(const string& name, Type type)
 {
     //XXX error checkint
-    vector<VariableBinding>::iterator itr
-        = find_if(bindings.begin(), bindings.end(),
-                  boost::bind(&VariableBinding::name, _1) == name);
+    std::vector<VariableBinding>::const_iterator itr =
+        std::find_if(bindings.begin(), bindings.end(),
+                     [&name] (const VariableBinding& v) {
+                         return v.name == name; });
     if (itr != bindings.end())
         return itr->location;
     size_t result = bindings.size();
@@ -881,11 +886,10 @@ size_t BindingLayout::addBinding(const string& name, Type type)
 bool BindingLayout::findBinding(const std::string& name,
                                 VariableBinding& result) const
 {
-    using namespace std;
-    using namespace boost;
-    vector<VariableBinding>::const_iterator itr
-        = find_if(bindings.begin(), bindings.end(),
-                  boost::bind(&VariableBinding::name, _1) == name);
+    std::vector<VariableBinding>::const_iterator itr =
+        std::find_if(bindings.begin(), bindings.end(),
+                     [&name] (const VariableBinding& v) {
+                         return v.name == name; });
     if (itr != bindings.end()) {
         result = *itr;
         return true;
